<?php

/*
 *	Helper functions
 *
 * 	@version	1.0
 * 	@author		Greatives Team
 * 	@URI		http://greatives.eu
 */


 /**
 * Generates a button
 * Used in shortcodes to display a button
 */
function grve_vce_get_button( $button_text, $button_text_hover, $button_link, $button_type, $button_size, $button_color, $style = '' ) {

	$button = $data = "";

	if ( !empty( $button_text ) ) {
		$button_classes = array( 'grve-btn' );

		array_push( $button_classes, 'grve-btn-' . $button_size );

		if ( !empty ( $button_color ) && 'simple' == $button_type ) {
			if ( 'primary' == $button_color ) {
				array_push( $button_classes, 'grve-primary' );
			} else {
				array_push( $button_classes, 'grve-' . $button_color . '-color' );
			}
		}

		if ( 'outline' == $button_type ) {
			array_push( $button_classes, 'grve-btn-line' );
		} else if ( 'advanced' == $button_type ) {
			array_push( $button_classes, 'grve-btn-line' );
			array_push( $button_classes, 'grve-btn-advanced' );

			if ( empty( $button_text_hover ) ) {
				$button_text_hover = $button_text;
			}
			$data = 'data-hover="' . $button_text_hover . '"';
		}

		$button_class_string = implode( ' ', $button_classes );

		if ( !empty( $button_link ) ){
			$href = vc_build_link( $button_link );
			$url = $href['url'];
			if ( !empty( $href['target'] ) ){
				$target = $href['target'];
			} else {
				$target= "_self";
			}
		} else {
			$url = "#";
			$target= "_self";
		}

		$button .= '<a class="' . $button_class_string . '" href="' . $url . '" ' . $data . ' target="' . $target . '" style="' . $style . '">';
		$button .= '<span>';
		$button .= $button_text;
		$button .= '</span>';
		$button .= '</a>';

	}

	return $button;

}

 /**
 * Fetch Portfolio Categories
 * Used in shortcodes to generate the list of used categories ( back end )
 */
function grve_vce_get_portfolio_categories() {

	$portfolio_category = array( __( "All Categories", "grve-vc-extension" ) => "" );

	$portfolio_cats = get_terms( 'portfolio_category' );
	if ( is_array( $portfolio_cats ) ) {
	  foreach ( $portfolio_cats as $portfolio_cat ) {
		$portfolio_category[$portfolio_cat->name] = $portfolio_cat->term_id;

	  }
	}
	return $portfolio_category;

}

 /**
 * Fetch Portfolio Categories
 * Used in portfolio filter to generate the list of used categories ( front end )
 */
function grve_vce_get_portfolio_list() {

	$all_string =  apply_filters( 'grve_vce_portfolio_string_all_categories', __( 'All', 'grve-vc-extension' ) );

	$get_portfolio_category = get_categories( array( 'taxonomy' => 'portfolio_category') );
	$portfolio_category_list = array( '0' => $all_string );

	foreach ( $get_portfolio_category as $portfolio_category ) {
		$portfolio_category_list[] = $portfolio_category->cat_name;
	}
	return $portfolio_category_list;

}

 /**
 * Fetch Testimonial Categories
 * Used in shortcodes to generate the list of used categories ( back end )
 */
function grve_vce_get_testimonial_categories() {
	$testimonial_category = array( __( "All Categories", "grve-vc-extension" ) => "" );

	$testimonial_cats = get_terms( 'testimonial_category' );
	if ( is_array( $testimonial_cats ) ) {
	  foreach ( $testimonial_cats as $testimonial_cat ) {
		$testimonial_category[$testimonial_cat->name] = $testimonial_cat->term_id;

	  }
	}
	return $testimonial_category;
}

 /**
 * Fetch Post Categories
 * Used in shortcodes to generate the list of used categories ( back end )
 */
function grve_vce_get_post_categories() {
	$category = array( __( "All Categories", "grve-vc-extension" ) => "" );

	$cats = get_terms( 'category' );
	if ( is_array( $cats ) ) {
	  foreach ( $cats as $cat ) {
		$category[$cat->name] = $cat->term_id;

	  }
	}
	return $category;
}


 /**
 * Generates dimension string to concat in attribute style
 */
function grve_vce_build_dimension( $dimension, $value ) {
	$fixed_dimension = '';

	if( ! empty( $dimension ) &&  ! empty( $value )  ) {
		$fixed_dimension .= $dimension . ': '.(preg_match('/(px|em|\%|pt|cm)$/', $value) ? $value : $value.'px').';';
	}
	return $fixed_dimension;
}

 /**
 * Generates margin-bottom string to concat in attribute style
 */
function grve_vce_build_margin_bottom_style( $margin_bottom ) {
	$style = '';
	if( $margin_bottom != '' ) {
		$style .= 'margin-bottom: '.(preg_match('/(px|em|\%|pt|cm)$/', $margin_bottom) ? $margin_bottom : $margin_bottom .'px').';';
	}
	return $style;
}

 /**
 * Generates padding-top string to concat in attribute style
 */
function grve_vce_build_padding_top_style( $padding_top ) {
	$style = '';
	if( $padding_top != '' ) {
		$style .= 'padding-top: '.(preg_match('/(px|em|\%|pt|cm)$/', $padding_top) ? $padding_top : $padding_top.'px').';';
	}
	return $style;
}

 /**
 * Generates padding-bottom string to concat in attribute style
 */
function grve_vce_build_padding_bottom_style( $padding_bottom ) {
	$style = '';
	if( $padding_bottom != '' ) {
		$style .= 'padding-bottom: '.(preg_match('/(px|em|\%|pt|cm)$/', $padding_bottom) ? $padding_bottom : $padding_bottom.'px').';';
	}
	return $style;
}

 /**
 * Prints blog class depending on the blog style
 */
function grve_vce_get_blog_class( $grve_blog_style = 'large-media'  ) {

	switch( $grve_blog_style ) {

		case 'grid-2':
		case 'grid-3':
			$grve_blog_style_class = '';
			break;

		case 'small-media':
			$grve_blog_style_class = 'grve-blog-small-media grve-margin-0';
			break;

		case 'labeled':
			$grve_blog_style_class = 'grve-blog-label';
			break;

		case 'masonry':
			$grve_blog_style_class = 'grve-blog-masonry';
			break;

		case 'large-media':
		default:
			$grve_blog_style_class = 'grve-blog-large-media grve-margin-0';
			break;

	}

	return $grve_blog_style_class;

}


 /**
 * Prints excerpt depending on the blog style and post format
 */
function grve_vce_print_post_title( $blog_style, $post_format ) {

	switch( $post_format ) {
		case 'link':
			echo '<a ' . grve_vce_print_post_link( 'link' ) . ' rel="bookmark">';
			the_content();
			echo '</a>';
			break;
		case 'quote':
			echo '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">';
			the_content();
			echo '</a>';
			break;
		default:
			 the_title( '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark"><h5 class="grve-post-title">', '</h5></a>' );
			break;
	}

}

 /**
 * Prints post link
 */
function grve_vce_print_post_link( $post_format = 'standard') {
	global $post;
	$post_id = $post->ID;

	$grve_link = get_permalink();
	$grve_target = '_self';

	if ( 'link' == $post_format ) {
		$grve_link = get_post_meta( $post_id, 'grve_post_link_url', true );
		$new_window = get_post_meta( $post_id, 'grve_post_link_new_window', true );

		if( empty( $grve_link ) ) {
			$grve_link = get_permalink();
		}

		if( !empty( $new_window ) ) {
			$grve_target = '_blank';
		}
	}

	return 'href="' . esc_url( $grve_link ) . '" target="' . $grve_target . '"';

}

/**
 * Prints excerpt depending on the blog style and post format
 */
function grve_vce_print_post_excerpt( $blog_style, $post_format, $autoexcerpt = '', $excerpt_length = '55', $excerpt_more = '' ) {

	if ( 'link' == $post_format || 'quote' == $post_format ) {
		return;
	}

	switch( $blog_style ) {
		case 'large-media':
			if ( empty( $autoexcerpt ) ) {
				if ( empty( $excerpt_more ) ) {
					the_content( '' );
				} else {
					global $more;
					$more = 0;
					the_content( grve_vce_read_more_string() );
				}
			} else {
				echo grve_vce_excerpt( $excerpt_length, $excerpt_more );
			}
			break;
		default:
			echo grve_vce_excerpt( $excerpt_length, $excerpt_more );
			break;
	}

}

/**
 * Returns read more link
 */
function grve_vce_read_more() {
	$read_more_string =  apply_filters( 'grve_vce_string_read_more', __( 'read more', 'grve-vc-extension' ) );
    return '<a class="grve-read-more" href="' . get_permalink( get_the_ID() ) . '">' . $read_more_string . '</a>';
}

/**
 * Returns read more string
 */
function grve_vce_read_more_string() {
	$read_more_string =  apply_filters( 'grve_vce_string_read_more', __( 'read more', 'grve-vc-extension' ) );
    return $read_more_string;
}

/**
 * Returns excerpt
 */
function grve_vce_excerpt( $limit, $more = "" ) {
	global $post;
	$post_id = $post->ID;

	if ( has_excerpt( $post_id ) ) {
		$excerpt = apply_filters( 'the_content', $post->post_excerpt );
	} else {
		$content = get_the_content('');
		$content = do_shortcode( $content );
		$content = apply_filters('the_content', $content);
		$content = str_replace(']]>', ']]>', $content);
		if ( 'yes' == $more ) {
			$excerpt = '<p>' . wp_trim_words( $content, $limit ) . '</p>';
			$excerpt .= grve_vce_read_more();
		} else{
			$excerpt = '<p>' . wp_trim_words( $content, $limit ) . '</p>';
		}
	}
	return	$excerpt;
}



/**
 * Prints feature media depending on the blog style and post format
 */
function grve_vce_print_post_feature_media( $grve_blog_style = 'large-media', $post_format ) {
	global $post, $wp_embed;

	$post_id = $post->ID;

	switch( $grve_blog_style ) {

		case 'small-media':
		case 'masonry':
		case 'grid-2':
		case 'grid-3':
			$image_size = 'grve-image-blog-small';
			$image_size_slider = 'grve-image-blog-small';
			break;
		case 'large-media':
		default:
			$image_size = 'grve-image-blog-large-resize';
			$image_size_slider = 'grve-image-blog-large';
			break;
	}
	$image_href = esc_url( get_permalink() );


	if ( ( '' == $post_format || 'image' == $post_format ) &&  has_post_thumbnail( $post_id ) ) {
?>
		<div class="grve-media">
			<a href="<?php echo $image_href; ?>"><?php the_post_thumbnail( $image_size ); ?></a>
		</div>
<?php

	} else if ( 'audio' == $post_format ) {

		$audio_mode = get_post_meta( $post_id, 'grve_post_type_audio_mode', true );
		$audio_mp3 = get_post_meta( $post_id, 'grve_post_audio_mp3', true );
		$audio_ogg = get_post_meta( $post_id, 'grve_post_audio_ogg', true );
		$audio_wav = get_post_meta( $post_id, 'grve_post_audio_wav', true );
		$audio_embed = get_post_meta( $post_id, 'grve_post_audio_embed', true );

		if( empty( $audio_mode ) && !empty( $audio_embed ) ) {
			$audio_output = '';
			$audio_output .= '<div class="grve-media">';
			$audio_output .= $audio_embed;
			$audio_output .= '</div>';
			echo $audio_output;
		} else {

			if ( !empty( $audio_mp3 ) || !empty( $audio_ogg ) || !empty( $audio_wav ) ) {

				$audio_output = '[audio ';

				if ( !empty( $audio_mp3 ) ) {
					$audio_output .= 'mp3="'. $audio_mp3 .'" ';
				}
				if ( !empty( $audio_ogg ) ) {
					$audio_output .= 'ogg="'. $audio_ogg .'" ';
				}
				if ( !empty( $audio_wav ) ) {
					$audio_output .= 'wav="'. $audio_wav .'" ';
				}

				$audio_output .= ']';

				echo '<div class="grve-media">';
				echo  do_shortcode( $audio_output );
				echo '</div>';

			}
		}
	} else if ( 'video' == $post_format ) {

		$video_mode = get_post_meta( $post_id, 'grve_post_type_video_mode', true );
		$video_webm = get_post_meta( $post_id, 'grve_post_video_webm', true );
		$video_mp4 = get_post_meta( $post_id, 'grve_post_video_mp4', true );
		$video_ogv = get_post_meta( $post_id, 'grve_post_video_ogv', true );
		$video_embed = get_post_meta( $post_id, 'grve_post_video_embed', true );

		$video_output = '';

		if( empty( $video_mode ) && !empty( $video_embed ) ) {
			$video_output .= '<div class="grve-media">';
			$video_output .= $wp_embed->run_shortcode( '[embed]' . $video_embed . '[/embed]' );
			$video_output .= '</div>';
		} else {

			if ( !empty( $video_webm ) || !empty( $video_mp4 ) || !empty( $video_ogv ) ) {
				$video_output .= '<div class="grve-media">';
				$video_output .= '  <video controls>';

				if ( !empty( $video_webm ) ) {
					$video_output .= '<source src="' . $video_webm . '" type="video/webm">';
				}
				if ( !empty( $video_mp4 ) ) {
					$video_output .= '<source src="' . $video_mp4 . '" type="video/mp4">';
				}
				if ( !empty( $video_ogv ) ) {
					$video_output .= '<source src="' . $video_ogv . '" type="video/ogg">';
				}
				$video_output .='  </video>';
				$video_output .= '</div>';

			}
		}
		echo  $video_output;
	} else if ( 'gallery' == $post_format ) {

		$slider_items = get_post_meta( $post_id, 'grve_post_slider_items', true );
		if ( 'large-media' == $grve_blog_style ) {
			$gallery_mode = get_post_meta( $post_id, 'grve_post_type_gallery_mode', true );
			if ( empty( $gallery_mode ) ) {
				$gallery_mode = 'stamp';
			}
		} else {
			$gallery_mode = 'slider';
		}

		if ( !empty( $slider_items ) ) {
			grve_vce_print_gallery_slider( $gallery_mode, $slider_items, $image_size  );
		}

	}

}

 /**
 * Prints Gallery or Slider
 */
function grve_vce_print_gallery_slider( $gallery_mode, $slider_items, $image_size_slider ) {

	$image_size_gallery_thumb = 'grve-image-medium-rect';

	if ( $gallery_mode == 'stamp' ) {

?>
	<div class="grve-media grve-stamp-masonry grve-gallery-popup" data-columns="5">
<?php
	foreach ( $slider_items as $slider_item ) {

		$media_id = $slider_item['id'];
		$full_src = wp_get_attachment_image_src( $media_id, 'full' );
		$image_full_url = esc_url( $full_src[0] );

		$thumb_src = wp_get_attachment_image_src( $media_id, $image_size_gallery_thumb );
		$image_thumb_url = esc_url( $thumb_src[0] );

		$alt = get_post_meta( $media_id, '_wp_attachment_image_alt', true );
		$alt = ! empty( $alt ) ? esc_attr( $alt ) : '';

		echo '
			<div class="grve-hover-item grve-stamp-element">
				<a href="' . $image_full_url . '">
					<img src="' . $image_thumb_url . '" alt="' . $alt . '">
					<div class="grve-hover-content">
						<div class="grve-hover-title"></div>
					</div>
				</a>
			</div>
		';
	}
?>
	</div>
<?php

	} else {
?>
	<div class="grve-media grve-slider">
		<ul class="slides">
<?php
		foreach ( $slider_items as $slider_item ) {
			$media_id = $slider_item['id'];
			$full_src = wp_get_attachment_image_src( $media_id, $image_size_slider );
			$image_url = esc_url( $full_src[0] );
			$alt = get_post_meta( $media_id, '_wp_attachment_image_alt', true );
			$alt = ! empty( $alt ) ? esc_attr( $alt ) : '';
			echo '<li><img src="' . $image_url . '" alt="' . $alt . '"></li>';
		}
?>
		</ul>
	</div>
<?php
	}
}

 /**
 * Prints post categories depending on the blog style
 */
function grve_vce_print_post_categories( $grve_blog_style = 'large-media' ) {

	$show_categories = false;
	if ( is_singular() ) {
		$show_categories = true;
	} else {
		switch( $grve_blog_style ) {

			case 'small-media':
			case 'large-media':
			default:
				$show_categories = true;
				break;
		}
	}

	if ( $show_categories ) {
		$in_categories_string =  apply_filters( 'grve_vce_blog_string_categories_in', __( 'in', 'grve-vc-extension' ) );
?>
		<span class="grve-post-categories">
			<?php echo $in_categories_string . ' '; ?><?php the_category(', '); ?>
		</span>
<?php

	}

}

 /**
 * Prints post date
 */
function grve_vce_print_post_date() {
?>
	<span class="grve-post-date">
		<?php echo get_the_date(); ?>
	</span>
<?php
}

 /**
 * Prints post comments
 */
function grve_vce_print_post_comments() {
	$no_comments_string =  apply_filters( 'grve_vce_blog_string_no_comments', __( 'no comments', 'grve-vc-extension' ) );
	$one_comment_string =  apply_filters( 'grve_vce_blog_string_one_comment', __( '1 comment', 'grve-vc-extension' ) );
	$comments_string =  apply_filters( 'grve_vce_blog_string_comments', __( 'comments', 'grve-vc-extension' ) );
?>
	<span class="grve-post-comments">
		<a href="<?php the_permalink(); ?>#commentform"><?php comments_number( $no_comments_string, $one_comment_string, '% ' . $comments_string ); ?></a>
	</span>
<?php
}

 /**
 * Prints post author avatar
 */
function grve_vce_print_post_author( $grve_blog_style, $post_format ) {
	if ( 'large-media' == $grve_blog_style ) {
		if ( 'quote' != $post_format && 'link' != $post_format ) {
?>
	<div class="grve-post-author">
		<?php echo get_avatar( get_the_author_meta( 'ID' ), 80 ); ?>
	</div>
<?php
		}
	}
}

 /**
 * Prints post author by depending on the blog style
 */
function grve_vce_print_post_author_by( $grve_blog_style = 'large-media' ) {

	switch( $grve_blog_style ) {

		case 'small-media':
		case 'large-media':
			$show_athor_by = true;
			break;
		default:
			$show_athor_by = false;
			break;
	}


	if ( $show_athor_by ) {
		$author_by_string =  apply_filters( 'grve_vce_blog_string_by_author', __( 'by', 'grve-vc-extension' ) );
?>
		<span class="grve-post-author-by">
			<?php echo $author_by_string . ' '; ?><?php the_author_posts_link(); ?>
		</span>
<?php

	}

}

 /**
 * Prints blog data depending on the blog style
 */
function grve_vce_print_blog_data( $grve_blog_style ) {

	switch( $grve_blog_style ) {

		case 'small-media':
			$grve_data_columns = '1';
			$grve_data_layout = 'fitRows';
			break;

		case 'labeled':
			$grve_data_columns = '4';
			$grve_data_layout = 'masonry';
			break;

		case 'masonry':
			$grve_data_columns = '3';
			$grve_data_layout = 'masonry';
			break;

		case 'grid-2':
			$grve_data_columns = '2';
			$grve_data_layout = 'fitRows';
			break;

		case 'grid-3':
			$grve_data_columns = '3';
			$grve_data_layout = 'fitRows';
			break;

		case 'large-media':
		default:
			$grve_data_columns = '1';
			$grve_data_layout = 'fitRows';
			break;
	}

	echo 'data-columns="' . $grve_data_columns . '" data-layout="' . $grve_data_layout . '"';

}

?>