<?php
/**
 * Gallery Shortcode
 */

if( !function_exists( 'grve_gallery_shortcode' ) ) {

	function grve_gallery_shortcode( $attr, $content ) {

		$output = $start_block = $end_block = $item_class = $class_fullwidth = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'ids' => '',
					'full_width' => '',
					'gallery_type' => 'fitrows',
					'gallery_columns' => '3',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$attr
			)
		);

		$attachments = explode( ",", $ids );

		if ( empty( $attachments ) ) {
			return '';
		}

		$image_size = 'grve-image-medium-rect';

		if ( 'yes' == $full_width ) {
			$class_fullwidth = 'grve-fullwidth-element';
		}

		$style = grve_vce_build_margin_bottom_style( $margin_bottom );

		switch( $gallery_type ) {
			case 'stamp':
				$start_block .= '<div class="grve-element grve-stamp-masonry grve-gallery-popup ' . $class_fullwidth . ' ' . $el_class.'" data-columns="5" style="' . $style . '">';
				$item_class .= 'grve-stamp-element';
				$end_block .= '</div>';
				break;
			case 'masonry':
				$start_block .= '<div class="grve-element grve-gallery grve-gallery-popup ' . $class_fullwidth . ' ' . $el_class.'" style="' . $style . '">';
				$start_block .= '  <div class="grve-isotope-container" data-columns="4" data-layout="masonry">';
				$item_class .= 'grve-isotope-item';
				$end_block .= '	</div>';
				$end_block .= '</div>';
				break;
			case 'fitrows':
			default:
				$start_block .= '<div class="grve-element grve-gallery grve-gallery-popup ' . $class_fullwidth . ' ' . $el_class.'" style="' . $style . '">';
				$start_block .= '  <div class="grve-isotope-container" data-columns="' . $gallery_columns . '" data-layout="fitRows">';
				$item_class .= 'grve-isotope-item';
				$end_block .= '	</div>';
				$end_block .= '</div>';
				break;
		}

		$output .= $start_block;

		$gallery_index = 0;

		
		foreach ( $attachments as $id ) {
			$gallery_index++;
			
			$stamp_class = '';
			if ( '1' == $gallery_index && 'stamp' == $gallery_type ) {
				$stamp_class = "grve-corner-stamp";
			}

			if ( 'masonry' == $gallery_type ) {
				$image_size = 'grve-image-medium-rect';
				if ( $gallery_index % 2  == 0 ) {
					$image_size = 'grve-image-medium';
				}
			}
			
			$image_link_href =  wp_get_attachment_url( $id );
			$thumb_src = wp_get_attachment_image_src( $id, $image_size );
			$full_src = wp_get_attachment_image_src( $id, 'full' );
			$caption = get_post_field( 'post_excerpt', $id );
			$alt = get_post_meta( $id, '_wp_attachment_image_alt', true );
			$alt = ! empty( $alt ) ? esc_attr( $alt ) : '';



			$output .= '  <div class="grve-hover-item ' . $item_class. ' ' . $stamp_class . '">';
			$output .= '    <a href="' . $full_src[0] . '">';
			$output .= '      <img src="' . $thumb_src[0] . '" alt="' . $alt . '">';
			$output .= '      <div class="grve-hover-content">';
			$output .= '        <div class="grve-hover-title">' . wptexturize( $caption ) . '</div>';
			$output .= '      </div>';
			$output .= '    </a>';
			$output .= '  </div>';

		}
		$output .= $end_block;

		return $output;

	}
	add_shortcode( 'grve_gallery', 'grve_gallery_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

vc_map( array(
	"name" => __( "Gallery", "grve-vc-extension" ),
	"description" => __( "Numerous styles, multiple columns for galleries", "grve-vc-extension" ),
	"base" => "grve_gallery",
	"class" => "",
	"icon"      => "icon-wpb-grve-gallery",
	"category" => __( "Content", "js_composer" ),
	"params" => array(
		array(
			"type" => "dropdown",
			"heading" => __( "Gallery type", "grve-vc-extension" ),
			"param_name" => "gallery_type",
			"value" => array(
				__( "Fit rows", "grve-vc-extension" ) => 'fitrows',
				__( "Masonry", "grve-vc-extension" ) => 'masonry',
				__( "Stamp", "grve-vc-extension" ) => 'stamp',
			),
			"description" => __( "Select your gallery type.", "grve-vc-extension" ),
			"admin_label" => true,
		),
		array(
			"type" => "dropdown",
			"heading" => __( "Columns", "grve-vc-extension" ),
			"param_name" => "gallery_columns",
			"value" => array( '3', '4', '5', '6' ),
			"description" => __( "Select number of columns.", "grve-vc-extension" ),
			"admin_label" => true,
			"dependency" => Array( 'element' => "gallery_type", 'value' => array( 'fitrows' ) ),
		),		
		array(
			"type" => 'checkbox',
			"heading" => __( "Full width", "grve-vc-extension" ),
			"param_name" => "full_width",
			"description" => __( "If selected, element will expand to full width.", "grve-vc-extension" ),
			"value" => Array( __( "Expand element to full width", "grve-vc-extension" ) => 'yes' ),
		),
		array(
			"type"			=> "attach_images",
			"admin_label"	=> true,
			"class"			=> "",
			"heading"		=> __( "Attach Images", "grve-vc-extension" ),
			"param_name"	=> "ids",
			"description"	=> __( "Select your gallery images.", "grve-vc-extension" ),
		),
		$grve_vce_add_margin_bottom,
		$grve_vce_add_el_class,
	)
) );

?>