<?php
/**
 * Google Map Shortcode
 */

if( !function_exists( 'grve_gmap_shortcode' ) ) {

	function grve_gmap_shortcode( $atts, $content ) {
		$output = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'map_lat' => '51.516221',
					'map_lng' => '-0.136986',
					'map_height' => '280',
					'map_marker' => '',
					'map_zoom' => 14,
					'full_width' => '',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$atts
			)
		);

		wp_enqueue_script( 'grve-googleapi-script' );
		wp_enqueue_script( 'grve-maps-script' );

		$gmap_classes = array( 'grve-element', 'grve-map' );

		if ( 'yes' == $full_width ) {
			array_push( $gmap_classes, 'grve-fullwidth-element' );
		}
		if ( !empty ( $el_class ) ) {
			array_push( $gmap_classes, $el_class );
		}
		$gmap_class_string = implode( ' ', $gmap_classes );

		$style = grve_vce_build_margin_bottom_style( $margin_bottom );
		if ( empty( $map_marker ) ) {
			$map_marker = get_template_directory_uri() . '/images/markers/markers.png';
		} else {
			$id = preg_replace('/[^\d]/', '', $map_marker);
			$full_src = wp_get_attachment_image_src( $id, 'full' );
			$map_marker = $full_src[0];
		}
		$data_map = 'data-marker="' . $map_marker . '" data-lat="' . $map_lat . '" data-lng="' . $map_lng . '" data-zoom="' . $map_zoom . '"';

		$output .= '<div class="'. $gmap_class_string . '" ' . $data_map . ' style="' . $style . grve_vce_build_dimension( 'height', $map_height ) . '"></div>';

		return $output;
	}
	add_shortcode( 'grve_gmap', 'grve_gmap_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

vc_map( array(
	"name" => __( "Google Map", "grve-vc-extension" ),
	"description" => __( "Freely place your Google Map", "grve-vc-extension" ),
	"base" => "grve_gmap",
	"class" => "",
	"icon"      => "icon-wpb-grve-gmap",
	"category" => __( "Content", "js_composer" ),
	"params" => array(
		array(
			"type" => 'checkbox',
			"heading" => __( "Full width", "grve-vc-extension" ),
			"param_name" => "full_width",
			"description" => __( "If selected, element will expand to full width.", "grve-vc-extension" ),
			"value" => Array( __( "Expand element to full width", "grve-vc-extension" ) => 'yes' ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Map Latitude", "grve-vc-extension" ),
			"param_name" => "map_lat",
			"value" => "51.516221",
			"description" => __( "Type map Latitude.", "grve-vc-extension" ),
			"admin_label" => true,
		),
		array(
			"type" => "textfield",
			"heading" => __( "Map Longtitude", "grve-vc-extension" ),
			"param_name" => "map_lng",
			"value" => "-0.136986",
			"description" => __( "Type map Longtitude.", "grve-vc-extension" ),
			"admin_label" => true,
		),
		array(
			"type" => "dropdown",
			"heading" => __( "Map Zoom", "grve-vc-extension" ),
			"param_name" => "map_zoom",
			"value" => array( 1, 2, 3 ,4, 5, 6, 7, 8 ,9 ,10 ,11 ,12, 13, 14, 15, 16, 17, 18, 19 ),
			"std" => 14,
			"description" => __( "Zoom of the map.", "grve-vc-extension" ),
			"admin_label" => true,
		),
		array(
			"type" => "textfield",
			"heading" => __( "Map Height", "grve-vc-extension" ),
			"param_name" => "map_height",
			"value" => "280",
			"description" => __( "Type map height.", "grve-vc-extension" ),
		),
		array(
			"type" => "attach_image",
			"heading" => __( "Custom marker", "grve-vc-extension" ),
			"param_name" => "map_marker",
			"description" => __( "Select an icon for custom marker.", "grve-vc-extension" ),
		),
		$grve_vce_add_margin_bottom,
		$grve_vce_add_el_class,
	)
) );

?>