<?php
/**
 * Icon Box Shortcode
 */

if( !function_exists( 'grve_icon_box_shortcode' ) ) {

	function grve_icon_box_shortcode( $atts, $content ) {

		$output = $link_start = $link_end = $retina_data = $data = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'title' => '',
					'icon' => '',
					'icon_type' => 'icon',
					'icon_size' => 'classic',
					'icon_char' => '',
					'icon_image' => '',
					'retina_icon_image' => '',
					'bg_white_box' => '',
					'align' => 'left',
					'link' => '',
					'animation' => '',
					'animation_delay' => '200',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$atts
			)
		);

		$icon_classes = array( 'grve-element' );

		if ( 'small' == $icon_size ) {
			array_push( $icon_classes, 'grve-icon-box-small' );
		} else {
			array_push( $icon_classes, 'grve-icon-box' );
			array_push( $icon_classes, 'grve-align-' . $align );
		}

		if ( 'yes' == $bg_white_box ) {
			array_push( $icon_classes, 'grve-white-box' );
		}

		if ( !empty( $animation ) ) {
			array_push( $icon_classes, 'grve-animated-item' );
			array_push( $icon_classes, $animation);
			$data = ' data-delay="' . $animation_delay . '"';
		}

		if ( !empty ( $el_class ) ) {
			array_push( $icon_classes, $el_class);
		}

		$icon_class_string = implode( ' ', $icon_classes );

		if ( !empty( $link ) ){
			$href = vc_build_link( $link );
			$url = $href['url'];
			if ( !empty( $href['target'] ) ){
				$target = $href['target'];
			} else {
				$target= "_self";
			}
		} else {
			$url = "#";
			$target= "_self";
		}
		if ( !empty( $link ) ) {
			$link_start = '<a href="' . $url . '" target="' . $target . '">';
			$link_end = '</a>';
		}


		$style = grve_vce_build_margin_bottom_style( $margin_bottom );

		$output .= '<div class="' . $icon_class_string . '" style="' . $style . '"' . $data . '>';

		$output .= $link_start;

		if ( 'image' == $icon_type ) {
			if ( !empty( $icon_image ) ) {
				$img_id = preg_replace('/[^\d]/', '', $icon_image);
				$img_src = wp_get_attachment_image_src( $img_id, 'full' );
				if ( !empty( $retina_icon_image ) ) {
					$img_retina_id = preg_replace('/[^\d]/', '', $retina_icon_image);
					$img_retina_src = wp_get_attachment_image_src( $img_retina_id, 'full' );
					$retina_data = ' data-at2x="' . $img_retina_src[0] . '"';
				}
				$output .= '  <div class="grve-icon"><img alt="icon" src="' . $img_src[0] . '"' . $retina_data . '></div>';
			}
		} else if( 'char' == $icon_type ) {
			$output .= '  <div class="grve-icon">'. $icon_char. '</div>';
		} else {
			$output .= '  <div class="grve-icon fa fa-'. $icon. '"></div>';
		}

		$output .= $link_end;

		$output .= '  <div class="grve-box-content">';

		$output .= $link_start;
		$output .= '      <h5 class="grve-box-title">' . $title. '</h5>';
		$output .= $link_end;

		$output .= '    <p>' . $content. '</p>';
		$output .= '  </div>';
		$output .= '</div>';

		return $output;
	}
	add_shortcode( 'grve_icon_box', 'grve_icon_box_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

vc_map( array(
	"name" => __( "Icon Box", "grve-vc-extension" ),
	"description" => __( "Add an icon, character or image with title and text", "grve-vc-extension" ),
	"base" => "grve_icon_box",
	"class" => "",
	"icon"      => "icon-wpb-grve-icon-box",
	"category" => __( "Content", "js_composer" ),
	"params" => array(
		array(
			"type" => "dropdown",
			"heading" => __( "Icon size", "grve-vc-extension" ),
			"param_name" => "icon_size",
			"value" => array(
				__( "Classic", "grve-vc-extension" ) => 'classic',
				__( "Small", "grve-vc-extension" ) => 'small',
			),
			"description" => '',
		),
		array(
			"type" => "dropdown",
			"heading" => __( "Icon type", "grve-vc-extension" ),
			"param_name" => "icon_type",
			"value" => array(
				__( "Icon", "grve-vc-extension" ) => 'icon',
				__( "Image", "grve-vc-extension" ) => 'image',
				__( "Character", "grve-vc-extension" ) => 'char',
			),
			"description" => '',
			"admin_label" => true,
		),
		array(
			"type" => "grve_icon",
			"heading" => __( 'Icon', "grve-vc-extension" ),
			"param_name" => "icon",
			"value" => 'adjust',
			"description" => __( "Select an icon.", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "icon_type", 'value' => array( 'icon' ) ),
		),
		array(
			"type" => "attach_image",
			"heading" => __( "Icon Image", "grve-vc-extension" ),
			"param_name" => "icon_image",
			"description" => __( "Select an icon image.", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "icon_type", 'value' => array( 'image' ) ),
		),
		array(
			"type" => "attach_image",
			"heading" => __( "Retina Icon Image", "grve-vc-extension" ),
			"param_name" => "retina_icon_image",
			"description" => __( "Select a 2x icon.", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "icon_type", 'value' => array( 'image' ) ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Character", "grve-vc-extension" ),
			"param_name" => "icon_char",
			"value" => "A",
			"description" => __( "Type a single character.", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "icon_type", 'value' => array( 'char' ) ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Title", "grve-vc-extension" ),
			"param_name" => "title",
			"value" => "Sample Title",
			"description" => __( "Enter icon box title.", "grve-vc-extension" ),
			"admin_label" => true,
		),
		array(
			"type" => "textarea",
			"heading" => __( "Text", "grve-vc-extension" ),
			"param_name" => "content",
			"value" => "",
			"description" => __( "Enter your content.", "grve-vc-extension" ),
		),
		array(
			"type" => "vc_link",
			"heading" => __( "Link", "grve-vc-extension" ),
			"param_name" => "link",
			"value" => "",
			"description" => __( "Enter link.", "grve-vc-extension" ),
		),
		array(
			"type" => "dropdown",
			"heading" => __( "Alignment", "grve-vc-extension" ),
			"param_name" => "align",
			"value" => array(
				__( "Left", "grve-vc-extension" ) => 'left',
				__( "Right", "grve-vc-extension" ) => 'right',
				__( "Center", "grve-vc-extension" ) => 'center',
			),
			"description" => '',
			"admin_label" => true,
			"dependency" => Array( 'element' => "icon_size", 'value' => array( 'classic' ) ),
		),
		array(
			"type" => 'checkbox',
			"heading" => __( "White Box Background", "grve-vc-extension" ),
			"param_name" => "bg_white_box",
			"description" => __( "If selected, element will have a white box background.", "grve-vc-extension" ),
			"value" => Array( __( "Apply White Box Background", "grve-vc-extension" ) => 'yes' ),
		),
		$grve_vce_add_animation,
		$grve_vce_add_animation_delay,
		$grve_vce_add_margin_bottom,
		$grve_vce_add_el_class,
	)
) );

?>