<?php
/**
 * Image Text Shortcode
 */

if( !function_exists( 'grve_image_text_shortcode' ) ) {

	function grve_image_text_shortcode( $atts, $content ) {

		$output = $data = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'title' => '',
					'image' => '',
					'video_popup' => '',
					'video_link' => '',
					'button_text' => '',
					'button_text_hover' => '',
					'button_link' => '',
					'button_type' => 'simple',
					'button_size' => 'extrasmall',
					'button_color' => 'primary',
					'animation' => '',
					'animation_delay' => '200',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$atts
			)
		);


		//Button
		$button = grve_vce_get_button( $button_text, $button_text_hover, $button_link, $button_type, $button_size, $button_color );

		$style = grve_vce_build_margin_bottom_style( $margin_bottom );


		$image_text_classes = array( 'grve-element', 'grve-image-text' );

		if ( !empty( $animation ) ) {
			array_push( $image_text_classes, 'grve-animated-item' );
			array_push( $image_text_classes, $animation);
			$data = ' data-delay="' . $animation_delay . '"';
		}
		if ( !empty( $el_class ) ) {
			array_push( $image_text_classes, $el_class);
		}
		$image_text_class_string = implode( ' ', $image_text_classes );


		$output .= '<div class="' . $image_text_class_string . '" style="' . $style . '"' . $data . '>';
		if ( !empty( $image ) ) {
			$img_id = preg_replace('/[^\d]/', '', $image);
			$img_src = wp_get_attachment_image_src( $img_id, 'full' );
			$alt = get_post_meta( $img_id, '_wp_attachment_image_alt', true );
			$alt = ! empty( $alt ) ? esc_attr( $alt ) : '';

			if ( 'yes' == $video_popup && !empty( $video_link ) ) {
				$output .= '<div class="grve-image">';
				$output .= '	<a class="grve-vimeo-popup grve-video-icon" href="' . $video_link . '">';
				$output .= '		<img alt="' . $alt . '" src="' . $img_src[0] . '">';
				$output .= '	</a>';
				$output .= '</div>';
			} else {
				$output .= '<div class="grve-image">';
				$output .= '  <img alt="' . $alt . '" src="' . $img_src[0] . '">';
				$output .= '</div>';
			}

		}

		$output .= '  <div class="grve-content">';
		$output .= '    <div class="grve-element grve-margin-10">';
		$output .= '      <h4>' . $title. '</h4>';
		$output .= '      <p>' . $content. '</p>';
		$output .= '    </div>';
		$output .= '    <div class="clear"></div>';
		$output .= $button;
		$output .= '  </div>';
		$output .= '</div>';

		return $output;
	}
	add_shortcode( 'grve_image_text', 'grve_image_text_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

vc_map( array(
	"name" => __( "Image Text", "grve-vc-extension" ),
	"description" => __( "Combine image or video with text and button", "grve-vc-extension" ),
	"base" => "grve_image_text",
	"class" => "",
	"icon"      => "icon-wpb-grve-image-text",
	"category" => __( "Content", "js_composer" ),
	"params" => array(
		array(
			"type" => "attach_image",
			"heading" => __( "Image", "grve-vc-extension" ),
			"param_name" => "image",
			"description" => __( "Select an image.", "grve-vc-extension" ),
		),
		array(
			"type" => 'dropdown',
			"heading" => __( "Video popup", "grve-vc-extension" ),
			"param_name" => "video_popup",
			"description" => __( "If selected, a video popup will be appear on click.", "grve-vc-extension" ),
			"value" => array(
				__( "No", "grve-vc-extension" ) => '',
				__( "Yes", "grve-vc-extension" ) => 'yes',
			),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Video Link", "grve-vc-extension" ),
			"param_name" => "video_link",
			"value" => "",
			"description" => __( "Type video URL e.g Vimeo/YouTube.", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "video_popup", 'not_empty' => true ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Title", "grve-vc-extension" ),
			"param_name" => "title",
			"value" => "Sample Title",
			"description" => __( "Enter your title.", "grve-vc-extension" ),
			"admin_label" => true,
		),
		array(
			"type" => "textarea",
			"heading" => __( "Text", "grve-vc-extension" ),
			"param_name" => "content",
			"value" => "Sample Text",
			"description" => __( "Enter your text.", "grve-vc-extension" ),
		),
		$grve_vce_add_button_type,
		$grve_vce_add_button_color,
		$grve_vce_add_button_text_empty,
		$grve_vce_add_button_text_hover,
		$grve_vce_add_button_size,
		$grve_vce_add_button_link,
		$grve_vce_add_animation,
		$grve_vce_add_animation_delay,
		$grve_vce_add_margin_bottom,
		$grve_vce_add_el_class,
	)
) );

?>