<?php
/**
 * Portfolio Shortcode
 */

if( !function_exists( 'grve_portfolio_shortcode' ) ) {

	function grve_portfolio_shortcode( $attr, $content ) {

		$portfolio_row_start = $allow_filter = $class_fullwidth = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'categories' => '',
					'full_width' => '',
					'portfolio_style' => 'grid-3',
					'portfolio_link_type' => 'item',
					'portfolio_filter' => '',
					'items_per_page' => '4',
					'items_to_show' => '12',
					'order_by' => 'date',
					'order' => 'DESC',
					'disable_pagination' => '',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$attr
			)
		);

		$portfolio_classes = array( 'grve-element' );

		switch( $portfolio_style ) {
			case 'masonry':
				$portfolio_row_start = '<div class="grve-isotope-container" data-columns="4" data-layout="masonry">';
				array_push( $portfolio_classes, 'grve-portfolio' );
				if ( 'yes' == $full_width ) {
					array_push( $portfolio_classes, 'grve-fullwidth-element' );
				}
				$allow_filter = 'yes';

				break;
			case 'carousel':
				$portfolio_row_start = '<div class="grve-carousel" data-columns="' . $items_per_page . '">';
				array_push( $portfolio_classes, 'grve-carousel-wrapper' );
				if ( 'yes' == $full_width ) {
					array_push( $portfolio_classes, 'grve-fullwidth-element' );
				}
				$disable_pagination = 'yes';
				break;
			case 'grid-4':
				$portfolio_row_start = '<div class="grve-isotope-container" data-columns="4" data-layout="fitRows">';
				array_push( $portfolio_classes, 'grve-portfolio' );
				$allow_filter = 'yes';
				break;
			case 'grid-5':
				$portfolio_row_start = '<div class="grve-isotope-container" data-columns="5" data-layout="fitRows">';
				array_push( $portfolio_classes, 'grve-portfolio' );
				$allow_filter = 'yes';
				break;
			case 'grid-3':
			default:
				$portfolio_row_start = '<div class="grve-isotope-container" data-columns="3" data-layout="fitRows">';
				array_push( $portfolio_classes, 'grve-portfolio' );
				$allow_filter = 'yes';
				break;
		}


		if ( !empty ( $el_class ) ) {
			array_push( $portfolio_classes, $el_class);
		}
		$portfolio_class_string = implode( ' ', $portfolio_classes );

		$style = grve_vce_build_margin_bottom_style( $margin_bottom );

		$portfolio_cat = "";

		if( ! empty( $categories ) ) {
			$portfolio_category_ids = explode( ",", $categories );
			foreach ( $portfolio_category_ids as $category_id ) {
				$category_term = get_term( $category_id, 'portfolio_category' );
				$portfolio_cat = $portfolio_cat.$category_term->slug . ', ';
			}
		}

		global $paged;
		$paged = 1;

		if ( 'yes' != $disable_pagination ) {
			if ( get_query_var( 'paged' ) ) {
				$paged = get_query_var( 'paged' );
			} elseif ( get_query_var( 'page' ) ) {
				$paged = get_query_var( 'page' );
			}
		}

		$args = array(
			'post_type' => 'portfolio',
			'post_status'=>'publish',
			'paged' => $paged,
			'portfolio_category' => $portfolio_cat,
			'posts_per_page' => $items_to_show,
			'orderby' => $order_by,
			'order' => $order,
		);

		$query = new WP_Query( $args );
		ob_start();
		if ( $query->have_posts() ) :
		?>
			<div class="<?php echo $portfolio_class_string; ?>" style="<?php echo $style; ?>">
		<?php

		if ( 'yes' == $portfolio_filter && 'yes' == $allow_filter ) {

			$portfolio_category_list = array( '0' => __( 'All', 'grve-vc-extension' ) );

			while ( $query->have_posts() ) : $query->the_post();

				if ( $portfolio_categories = get_the_terms( get_the_ID(), 'portfolio_category' ) ) {

					foreach($portfolio_categories as $category_term){
						if ( !in_array($category_term->name, $portfolio_category_list) ) {
							$portfolio_category_list[] = $category_term->name;
						}
					}
				}

			endwhile;

			if ( count( $portfolio_category_list ) > 2 ) {


		?>
				<div class="grve-filter grve-align-center">
					<ul>
		<?php
						foreach ( $portfolio_category_list as $category_list ) {
							$selected = '';
							$category_term = get_term_by( 'name', $category_list , 'portfolio_category' );

							if ( ! empty( $category_term ) ) {
								$category_slug = '.portfolio_category_' . $category_term->slug . $unique_id;
							} else {
								$category_slug = '*';
								$selected = 'selected';
							}
							echo '<li data-filter="' . $category_slug . '" class="'. $selected . '">' . $category_list . '</li>';
						}
		?>
					</ul>
				</div>
		<?php
			}
		}
		?>

				<?php echo $portfolio_row_start; ?>

		<?php
		while ( $query->have_posts() ) : $query->the_post();

			if ( 'carousel' == $portfolio_style ) {
				get_template_part( 'templates/portfolio', 'carousel' );
			} else if  ( 'masonry' == $portfolio_style ) {
				if ( 'popup' == $portfolio_link_type ) {
					get_template_part( 'templates/portfolio', 'masonry-gallery' );
				} else {
					get_template_part( 'templates/portfolio', 'masonry' );
				}
			} else {
				if ( 'popup' == $portfolio_link_type ) {
					get_template_part( 'templates/portfolio', 'grid-gallery' );
				} else {
					get_template_part( 'templates/portfolio', 'grid' );
				}
			}

		endwhile;

		?>
				</div>
<?php
			if ( 'yes' != $disable_pagination ) {
				$total = $query->max_num_pages;
				$big = 999999999; // need an unlikely integer
				if( $total > 1 )  {
					 echo '<div class="grve-pagination">';

					 if( !$current_page = $paged )
						 $current_page = 1;
					 if( get_option('permalink_structure') ) {
						 $format = 'page/%#%/';
					 } else {
						 $format = '&paged=%#%';
					 }
					 echo paginate_links(array(
						'base'			=> str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
						'format'		=> $format,
						'current'		=> max( 1, $paged ),
						'total'			=> $total,
						'mid_size'		=> 2,
						'type'			=> 'list',
						'prev_text'	=> '<i class="fa fa-angle-left"></i>',
						'next_text'	=> '<i class="fa fa-angle-right"></i>',
					 ));
					 echo '</div>';
				}
			}
?>
			</div>

		<?php

		else :
		endif;
		wp_reset_postdata();

		return ob_get_clean();

	}
	add_shortcode( 'grve_portfolio', 'grve_portfolio_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

vc_map( array(
	"name" => __( "Portfolio", "grve-vc-extension" ),
	"description" => __( "Display Portfolio element in multiple styles", "grve-vc-extension" ),
	"base" => "grve_portfolio",
	"class" => "",
	"icon"      => "icon-wpb-grve-portfolio",
	"category" => __( "Content", "js_composer" ),
	"params" => array(
		array(
			"type" => "dropdown",
			"heading" => __( "Style", "grve-vc-extension" ),
			"param_name" => "portfolio_style",
			"admin_label" => true,
			'value' => array(
				__( 'Grid 3 Columns' , 'grve-vc-extension' ) => 'grid-3',
				__( 'Grid 4 Columns' , 'grve-vc-extension' ) => 'grid-4',
				__( 'Grid 5 Columns' , 'grve-vc-extension' ) => 'grid-5',
				__( 'Masonry' , 'grve-vc-extension' ) => 'masonry',
				__( 'Carousel' , 'grve-vc-extension' ) => 'carousel',
			),
			"description" => __( "Select a style for your portfolio", "grve-vc-extension" ),
		),
		array(
			"type" => "dropdown",
			"heading" => __( "Link Type", "grve-vc-extension" ),
			"param_name" => "portfolio_link_type",
			"admin_label" => true,
			'value' => array(
				__( 'Portfolio Item' , 'grve-vc-extension' ) => 'item',
				__( 'Gallery Popup' , 'grve-vc-extension' ) => 'popup',
			),
			"description" => __( "Select the link type of your portfolio items.", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid-3', 'grid-4', 'grid-5', 'masonry' ) ),
		),
		array(
			"type" => "grve_multi_checkbox",
			"heading" => __("Portfolio Categories", "grve-vc-extension" ),
			"param_name" => "categories",
			"value" => grve_vce_get_portfolio_categories(),
			"description" => __( "Select all or multiple categories.", "grve-vc-extension" ),
			"admin_label" => true,
			"group" => __( "Categories", "grve-vc-extension" ),
		),
		array(
			"type" => 'checkbox',
			"heading" => __( "Full width", "grve-vc-extension" ),
			"param_name" => "full_width",
			"description" => __( "If selected, element will expand to full width.", "grve-vc-extension" ),
			"value" => Array( __( "Expand element to full width", "grve-vc-extension" ) => 'yes' ),
			"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'carousel', 'masonry' ) ),
		),
		array(
			"type" => 'checkbox',
			"heading" => __( "Filter", "grve-vc-extension" ),
			"param_name" => "portfolio_filter",
			"description" => __( "If selected, an isotope filter will be displayed.", "grve-vc-extension" ),
			"value" => Array( __( "Enable Portfolio Filter ( Only for All or Multiple Categories )", "grve-vc-extension" ) => 'yes' ),
			"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid-3', 'grid-4', 'grid-5', 'masonry' ) ),
		),
		array(
			"type" => 'checkbox',
			"heading" => __( "Disable Pagination", "grve-vc-extension" ),
			"param_name" => "disable_pagination",
			"description" => __( "If selected, pagination will not be shown.", "grve-vc-extension" ),
			"value" => Array( __( "Disable Pagination.", "grve-vc-extension" ) => 'yes' ),
			"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'grid-3', 'grid-4', 'grid-5', 'masonry' ) ),
		),
		array(
			"type" => "dropdown",
			"heading" => __( "Items per page", "grve-vc-extension" ),
			"param_name" => "items_per_page",
			"value" => array( '3', '4', '5', '6' ),
			"description" => __( "Number of images per page", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "portfolio_style", 'value' => array( 'carousel' ) ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Items to show", "grve-vc-extension" ),
			"param_name" => "items_to_show",
			"value" => '12',
			"description" => __( "Maximum Portfolio Items to Show", "grve-vc-extension" ),
		),
		$grve_vce_add_order_by,
		$grve_vce_add_order,
		$grve_vce_add_margin_bottom,
		$grve_vce_add_el_class,
	)
) );

?>