<?php
/**
 * Pricing Table Shortcode
 */

if( !function_exists( 'grve_pricing_table_shortcode' ) ) {

	function grve_pricing_table_shortcode( $atts, $content ) {

		$output = $data = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'title' => '',
					'price' => '',
					'interval' => '',
					'feature' => '',
					'values' => '',
					'button_text' => '',
					'button_text_hover' => '',
					'button_link' => '',
					'button_type' => 'simple',
					'button_size' => 'extrasmall',
					'button_color' => 'primary',
					'bg_color' => '',
					'animation' => '',
					'animation_delay' => '200',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$atts
			)
		);

		$button = grve_vce_get_button( $button_text, $button_text_hover, $button_link, $button_type, $button_size, $button_color );

		//Pricing Table Classes
		$pricing_classes = array( 'grve-element', 'grve-pricing-table' );
		if( 'yes' == $feature ) {
			array_push( $pricing_classes, 'grve-pricing-feature' );
		}
		if ( !empty( $animation ) ) {
			array_push( $pricing_classes, 'grve-animated-item' );
			array_push( $pricing_classes, $animation);
			$data = ' data-delay="' . $animation_delay . '"';
		}

		if ( !empty ( $el_class ) ) {
			array_push( $pricing_classes, $el_class);
		}
		$pricing_class_string = implode( ' ', $pricing_classes );

		//Pricing Lines
		$pricing_lines = explode(",", $values);

		$pricing_lines_data = array();
		foreach ($pricing_lines as $line) {
			$new_line = array();
			$data_line = explode("|", $line);
			$new_line['value1'] = isset( $data_line[0] ) && !empty( $data_line[0] ) ? $data_line[0] : '';
			$new_line['value2'] = isset( $data_line[1] ) && !empty( $data_line[1] ) ? $data_line[1] : '';
			$pricing_lines_data[] = $new_line;
		}

		$style = grve_vce_build_margin_bottom_style( $margin_bottom );

		$output .= '<div class="' . $pricing_class_string . '" style="' . $style . '"' . $data . '>';
		$output .= '  <div class="grve-pricing-header">';
		$output .= '    <h6 class="grve-pricing-title">' . $title . '</h6>';
		$output .= '    <h2 class="grve-price">' . $price . ' <span>' . $interval . '</span></h2>';
	    $output .= '  </div>';
	    $output .= '  <ul>';
		foreach($pricing_lines_data as $line) {
			$output .= '<li><strong>' .  $line['value1'] . ' </strong>' .  $line['value2'] . '</li>';
		}
		$output .= '  </ul>';
		$output .= $button;
		$output .= '</div>';

		return $output;
	}
	add_shortcode( 'grve_pricing_table', 'grve_pricing_table_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

vc_map( array(
	"name" => __( "Pricing Table", "grve-vc-extension" ),
	"description" => __( "Stylish pricing tables", "grve-vc-extension" ),
	"base" => "grve_pricing_table",
	"class" => "",
	"icon"      => "icon-wpb-grve-pricing-table",
	"category" => __( "Content", "js_composer" ),
	"params" => array(
		array(
			"type" => "textfield",
			"heading" => __( "Title", "grve-vc-extension" ),
			"param_name" => "title",
			"value" => "Title",
			"description" => __( "Enter your title here.", "grve-vc-extension" ),
			"admin_label" => true,
		),
		array(
			"type" => "textfield",
			"heading" => __( "Price", "grve-vc-extension" ),
			"param_name" => "price",
			"value" => "$0",
			"description" => __( "Enter your price here. eg $80.", "grve-vc-extension" ),
			"admin_label" => true,
		),
		array(
			"type" => "textfield",
			"heading" => __( "Interval", "grve-vc-extension" ),
			"param_name" => "interval",
			"value" => "/month",
			"description" => __( "Enter interval period here. e.g: /month, per month, per year.", "grve-vc-extension" ),
		),
		array(
			"type" => "exploded_textarea",
			"heading" => __("Attributes", "grve-vc-extension"),
			"param_name" => "values",
			"description" => __( "Input attribute values. Divide values with linebreaks (Enter). Example: 100|Users.", "grve-vc-extension" ),
			"value" => "100|Users,8 Gig|Disc Space,Unlimited|Data Transfer",
		),
		array(
			"type" => 'checkbox',
			"heading" => __( "Featured", "grve-vc-extension" ),
			"param_name" => "feature",
			"description" => __( "If selected, element will be shown as feature.", "grve-vc-extension" ),
			"value" => Array( __( "Show as featured", "grve-vc-extension" ) => 'yes' ),
		),
		array(
			"type" => "dropdown",
			"heading" => __( "Button type", "grve-vc-extension" ),
			"param_name" => "button_type",
			"value" => array(
				__( "Simple", "grve-vc-extension" ) => 'simple',
				__( "Outline", "grve-vc-extension" ) => 'outline',
				__( "Advanced", "grve-vc-extension" ) => 'advanced',
			),
			"description" => __( "Select button type.", "grve-vc-extension" ),
		),
		array(
			"type" => "dropdown",
			"heading" => __( "Button Color", "grve-vc-extension" ),
			"param_name" => "button_color",
			"value" => array(
				__( "Primary", "grve-vc-extension" ) => 'primary',
				__( "Green", "grve-vc-extension" ) => 'green',
				__( "Orange", "grve-vc-extension" ) => 'orange',
				__( "Red", "grve-vc-extension" ) => 'red',
				__( "Blue", "grve-vc-extension" ) => 'blue',
				__( "Aqua", "grve-vc-extension" ) => 'aqua',
				__( "Purple", "grve-vc-extension" ) => 'purple',
				__( "Black", "grve-vc-extension" ) => 'black',
				__( "White", "grve-vc-extension" ) => 'white',
			),
			"description" => __( "Color of the button.", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "button_type", 'value' => array( 'simple' ) ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Button Text", "grve-vc-extension" ),
			"param_name" => "button_text",
			"value" => "Button",
			"description" => __( "Text of the button.", "grve-vc-extension" ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Button Text Hover", "grve-vc-extension" ),
			"param_name" => "button_text_hover",
			"value" => "Button",
			"description" => __( "Text of the button on hover.", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "button_type", 'value' => array( 'advanced' ) ),
		),
		array(
			"type" => "dropdown",
			"heading" => __( "Button Size", "grve-vc-extension" ),
			"param_name" => "button_size",
			"value" => array(
				__( "Extra Small", "grve-vc-extension" ) => 'extrasmall',
				__( "Small", "grve-vc-extension" ) => 'small',
				__( "Medium", "grve-vc-extension" ) => 'medium',
				__( "Large", "grve-vc-extension" ) => 'large',
			),
			"description" => '',
		),
		array(
			"type" => "vc_link",
			"heading" => __( "Button Link", "grve-vc-extension" ),
			"param_name" => "button_link",
			"value" => "",
			"description" => __( "Enter link.", "grve-vc-extension" ),
		),
		$grve_vce_add_animation,
		$grve_vce_add_animation_delay,
		$grve_vce_add_margin_bottom,
		$grve_vce_add_el_class,
	)
) );

?>