<?php
/**
 * Single Image Shortcode
 */

if( !function_exists( 'grve_single_image_shortcode' ) ) {

	function grve_single_image_shortcode( $attr, $content ) {

		$output = $data = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'image' => '',
					'image_type' => 'image',
					'link' => '',
					'video_link' => '',
					'animation' => '',
					'animation_delay' => '200',
					'align' => 'left',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$attr
			)
		);

		if ( !empty( $link ) ){
			$href = vc_build_link( $link );
			$url = $href['url'];
			if ( !empty( $href['target'] ) ){
				$target = $href['target'];
			} else {
				$target= "_self";
			}
		} else {
			$url = "#";
			$target= "_self";
		}

		$image_size = 'full';

		$single_image_classes = array( 'grve-element', 'grve-image', 'grve-align-' . $align );

		if ( !empty( $animation ) ) {
			array_push( $single_image_classes, 'grve-animated-item' );
			array_push( $single_image_classes, $animation);
			$data = ' data-delay="' . $animation_delay . '"';
		}
		if ( !empty( $el_class ) ) {
			array_push( $single_image_classes, $el_class);
		}
		$single_image_classe_string = implode( ' ', $single_image_classes );


		$style = grve_vce_build_margin_bottom_style( $margin_bottom );

		$output .= '<div class="' . $single_image_classe_string . '" style="' . $style . '"' . $data . '>';

		if ( !empty( $image ) ) {
			$id = preg_replace('/[^\d]/', '', $image);
			$image_link_href =  wp_get_attachment_url( $id );
			$thumb_src = wp_get_attachment_image_src( $id, $image_size );
			$full_src = wp_get_attachment_image_src( $id, 'large' );

			$alt = get_post_meta( $id, '_wp_attachment_image_alt', true );
			$alt = ! empty( $alt ) ? esc_attr( $alt ) : '';

			if ( 'image-popup' == $image_type ) {
				$output .= '<a class="grve-image-popup" href="' . $full_src[0] . '">';
				$output .= '  <img src="' . $thumb_src[0] . '" alt="' . $alt . '">';
				$output .= '</a>';
			} else if ( 'image-link' == $image_type ) {
				$output .= '<a href="' . $url . '" target="' . $target . '">';
				$output .= '  <img alt="' . $alt . '" src="' . $thumb_src[0] . '">';
				$output .= '</a>';
			} else if ( 'image-video-popup' == $image_type ) {
				if ( !empty( $video_link ) ) {
					$output .= '<div class="grve-media">';
					$output .= '	<a class="grve-vimeo-popup grve-video-icon" href="' . $video_link . '">';
					$output .= '		<img alt="' . $alt . '" src="' . $thumb_src[0] . '">';
					$output .= '	</a>';
					$output .= '</div>';
				} else {
					$output .= '<div class="grve-media">';
					$output .= '  <img alt="' . $alt . '" src="' . $thumb_src[0] . '">';
					$output .= '</div>';
				}
			} else {
				$output .= '  <img alt="' . $alt . '" src="' . $thumb_src[0] . '">';
			}
		}

		$output .= '</div>';

		return $output;

	}
	add_shortcode( 'grve_single_image', 'grve_single_image_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

vc_map( array(
	"name" => __( "Single Image", "grve-vc-extension" ),
	"description" => __( "Image or Video popup in various uses", "grve-vc-extension" ),
	"base" => "grve_single_image",
	"class" => "",
	"icon"      => "icon-wpb-grve-single-image",
	"category" => __( "Content", "js_composer" ),
	"params" => array(
		array(
			"type" => "dropdown",
			"heading" => __( "Image type", "grve-vc-extension" ),
			"param_name" => "image_type",
			"value" => array(
				__( "Image", "grve-vc-extension" ) => 'image',
				__( "Image Link", "grve-vc-extension" ) => 'image-link',
				__( "Image Popup", "grve-vc-extension" ) => 'image-popup',
				__( "Image Video Popup", "grve-vc-extension" ) => 'image-video-popup',
			),
			"description" => __( "Select your image type.", "grve-vc-extension" ),
			"admin_label" => true,
		),
		array(
			"type" => "attach_image",
			"heading" => __( "Image", "grve-vc-extension" ),
			"param_name" => "image",
			"description" => __( "Select an image.", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "image_type", 'value' => array( 'image', 'image-link', 'image-video-popup') ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Video Link", "grve-vc-extension" ),
			"param_name" => "video_link",
			"value" => "",
			"description" => __( "Type video URL e.g Vimeo/YouTube.", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "image_type", 'value' => array( 'image-video-popup') ),
		),
		array(
			"type" => "vc_link",
			"heading" => __( "Link", "grve-vc-extension" ),
			"param_name" => "link",
			"value" => "",
			"description" => __( "Enter link.", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "image_type", 'value' => array( 'image-link' ) ),
		),
		$grve_vce_add_align,
		$grve_vce_add_animation,
		$grve_vce_add_animation_delay,
		$grve_vce_add_margin_bottom,
		$grve_vce_add_el_class,
	)
) );

?>