<?php
/**
 * Slogan Shortcode
 */

if( !function_exists( 'grve_slogan_shortcode' ) ) {

	function grve_slogan_shortcode( $atts, $content ) {

		$output = $data = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'title' => '',
					'heading' => 'h1',
					'line_type' => 'no-line',
					'light_text' => '',
					'subtitle' => '',
					'button_text' => '',
					'button_text_hover' => '',
					'button_link' => '',
					'button_type' => 'simple',
					'button_size' => 'extrasmall',
					'button_color' => 'primary',
					'button2_text' => '',
					'button2_text_hover' => '',
					'button2_link' => '',
					'button2_type' => 'simple',
					'button2_size' => 'extrasmall',
					'button2_color' => 'primary',
					'align' => 'left',
					'animation' => '',
					'animation_delay' => '200',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$atts
			)
		);

		//Title
		if ( !empty( $title ) ) {
			//Title Classes
			$title_classes = array( 'grve-slogan-title' );

			array_push( $title_classes, 'grve-align-' . $align );
			array_push( $title_classes, 'grve-title-' . $line_type );

			if ( 'yes' == $light_text ) {
				array_push( $title_classes, 'grve-light-text' );
			}

			$title_class_string = implode( ' ', $title_classes );
		}

		//Slogan
		$slogan_classes = array( 'grve-element', 'grve-slogan', 'grve-align-' . $align );

		if ( !empty( $animation ) ) {
			array_push( $slogan_classes, 'grve-animated-item' );
			array_push( $slogan_classes, $animation);
			$data = ' data-delay="' . $animation_delay . '"';
		}
		if ( !empty( $el_class ) ) {
			array_push( $slogan_classes, $el_class);
		}
		$slogan_class_string = implode( ' ', $slogan_classes );

		//First Button
		$button1 = grve_vce_get_button( $button_text, $button_text_hover, $button_link, $button_type, $button_size, $button_color );
		//Second Button
		$button2 = grve_vce_get_button( $button2_text, $button2_text_hover, $button2_link, $button2_type, $button2_size, $button2_color );

		$style = grve_vce_build_margin_bottom_style( $margin_bottom );

		$output .= '<div class="' . $slogan_class_string . '" style="' . $style. '"' . $data . '>';
		if ( !empty( $subtitle ) ) {
			$output .= '<div class="grve-slogan-subtitle">' . $subtitle . '</div>';
		}
		if ( !empty( $title ) ) {
			$output .= '<' . $heading . ' class="' . $title_class_string . '">' . $title . '</' . $heading . '>';
		}
		$output .= '  <p>' . $content . '</p>';

		$output .= $button1;
		$output .= $button2;

		$output .= '</div>';

		return $output;
	}
	add_shortcode( 'grve_slogan', 'grve_slogan_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

vc_map( array(
	"name" => __( "Slogan", "grve-vc-extension" ),
	"description" => __( "Create easily appealing slogans", "grve-vc-extension" ),
	"base" => "grve_slogan",
	"class" => "",
	"icon"      => "icon-wpb-grve-slogan",
	"category" => __( "Content", "js_composer" ),
	"params" => array(
		array(
			"type" => "textfield",
			"heading" => __( "Title", "grve-vc-extension" ),
			"param_name" => "title",
			"value" => "Sample Title",
			"description" => __( "Enter your title here.", "grve-vc-extension" ),
			"admin_label" => true,
		),
		array(
			"type" => "dropdown",
			"heading" => __( "Heading", "grve-vc-extension" ),
			"param_name" => "heading",
			"admin_label" => true,
			"value" => array( 'h1', 'h2', 'h3', 'h4' , 'h5', 'h6' ),
			"description" => __( "Heading size of the title", "grve-vc-extension" ),
		),
		array(
			"type" => "dropdown",
			"heading" => __( "Line type", "grve-vc-extension" ),
			"param_name" => "line_type",
			"value" => array(
				__( "None", "grve-vc-extension" ) => 'no-line',
				__( "Simple", "grve-vc-extension" ) => 'line',
				__( "Double", "grve-vc-extension" ) => 'double-line',
				__( "Striped", "grve-vc-extension" ) => 'striped',
			),
			"description" => __( "Line Type of the title.", "grve-vc-extension" ),
		),
		array(
			"type" => 'checkbox',
			"heading" => __( "Light text", "grve-vc-extension" ),
			"param_name" => "light_text",
			"description" => __( "If selected, title will lighten up", "grve-vc-extension" ),
			"value" => Array( __( "Apply light text", "grve-vc-extension" ) => 'yes' ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Sub-Title", "grve-vc-extension" ),
			"param_name" => "subtitle",
			"value" => "",
			"description" => __( "Enter your sub-title here.", "grve-vc-extension" ),
			"admin_label" => true,
		),
		array(
			"type" => "textarea",
			"heading" => __( "Text", "grve-vc-extension" ),
			"param_name" => "content",
			"value" => "Sample Text",
			"description" => __( "Type your text.", "grve-vc-extension" ),
			"admin_label" => true,
		),
		array(
			"type" => "dropdown",
			"heading" => __( "First Button type", "grve-vc-extension" ),
			"param_name" => "button_type",
			"value" => array(
				__( "Simple", "grve-vc-extension" ) => 'simple',
				__( "Outline", "grve-vc-extension" ) => 'outline',
				__( "Advanced", "grve-vc-extension" ) => 'advanced',
			),
			"description" => __( "Select button type.", "grve-vc-extension" ),
			"group" => __( "First Button", "grve-vc-extension" ),
		),
		array(
			"type" => "dropdown",
			"heading" => __( "First Button Color", "grve-vc-extension" ),
			"param_name" => "button_color",
			"value" => array(
				__( "Primary", "grve-vc-extension" ) => 'primary',
				__( "Green", "grve-vc-extension" ) => 'green',
				__( "Orange", "grve-vc-extension" ) => 'orange',
				__( "Red", "grve-vc-extension" ) => 'red',
				__( "Blue", "grve-vc-extension" ) => 'blue',
				__( "Aqua", "grve-vc-extension" ) => 'aqua',
				__( "Purple", "grve-vc-extension" ) => 'purple',
				__( "Black", "grve-vc-extension" ) => 'black',
				__( "White", "grve-vc-extension" ) => 'white',
			),
			"description" => __( "Color of the button.", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "button_type", 'value' => array( 'simple' ) ),
			"group" => __( "First Button", "grve-vc-extension" ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "First Button Text", "grve-vc-extension" ),
			"param_name" => "button_text",
			"value" => "",
			"description" => __( "Leave this field empty if you don't want to show this button.", "grve-vc-extension" ),
			"group" => __( "First Button", "grve-vc-extension" ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "First Button Text Hover", "grve-vc-extension" ),
			"param_name" => "button_text_hover",
			"value" => "",
			"description" => __( "Text of the button on hover.", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "button_type", 'value' => array( 'advanced' ) ),
			"group" => __( "First Button", "grve-vc-extension" ),
		),
		array(
			"type" => "dropdown",
			"heading" => __( "First Button Size", "grve-vc-extension" ),
			"param_name" => "button_size",
			"value" => array(
				__( "Extra Small", "grve-vc-extension" ) => 'extrasmall',
				__( "Small", "grve-vc-extension" ) => 'small',
				__( "Medium", "grve-vc-extension" ) => 'medium',
				__( "Large", "grve-vc-extension" ) => 'large',
			),
			"description" => '',
			"admin_label" => true,
			"group" => __( "First Button", "grve-vc-extension" ),
		),
		array(
			"type" => "vc_link",
			"heading" => __( "First Button Link", "grve-vc-extension" ),
			"param_name" => "button_link",
			"value" => "",
			"description" => __( "Enter a link for your button.", "grve-vc-extension" ),
			"group" => __( "First Button", "grve-vc-extension" ),
		),

		array(
			"type" => "dropdown",
			"heading" => __( "Second Button type", "grve-vc-extension" ),
			"param_name" => "button2_type",
			"value" => array(
				__( "Simple", "grve-vc-extension" ) => 'simple',
				__( "Outline", "grve-vc-extension" ) => 'outline',
				__( "Advanced", "grve-vc-extension" ) => 'advanced',
			),
			"description" => __( "Select button type.", "grve-vc-extension" ),
			"group" => __( "Second Button", "grve-vc-extension" ),
		),
		array(
			"type" => "dropdown",
			"heading" => __( "Second Button Color", "grve-vc-extension" ),
			"param_name" => "button2_color",
			"value" => array(
				__( "Primary", "grve-vc-extension" ) => 'primary',
				__( "Green", "grve-vc-extension" ) => 'green',
				__( "Orange", "grve-vc-extension" ) => 'orange',
				__( "Red", "grve-vc-extension" ) => 'red',
				__( "Blue", "grve-vc-extension" ) => 'blue',
				__( "Aqua", "grve-vc-extension" ) => 'aqua',
				__( "Purple", "grve-vc-extension" ) => 'purple',
				__( "Black", "grve-vc-extension" ) => 'black',
				__( "White", "grve-vc-extension" ) => 'white',
			),
			"description" => __( "Color of the button.", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "button2_type", 'value' => array( 'simple' ) ),
			"group" => __( "Second Button", "grve-vc-extension" ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Second Button Text", "grve-vc-extension" ),
			"param_name" => "button2_text",
			"value" => "",
			"description" => __( "Leave this field empty if you don't want to show this button.", "grve-vc-extension" ),
			"group" => __( "Second Button", "grve-vc-extension" ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Second Button Text Hover", "grve-vc-extension" ),
			"param_name" => "button2_text_hover",
			"value" => "",
			"description" => __( "Text of the button on hover.", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "button2_type", 'value' => array( 'advanced' ) ),
			"group" => __( "Second Button", "grve-vc-extension" ),
		),
		array(
			"type" => "dropdown",
			"heading" => __( "Second Button Size", "grve-vc-extension" ),
			"param_name" => "button2_size",
			"value" => array(
				__( "Extra Small", "grve-vc-extension" ) => 'extrasmall',
				__( "Small", "grve-vc-extension" ) => 'small',
				__( "Medium", "grve-vc-extension" ) => 'medium',
				__( "Large", "grve-vc-extension" ) => 'large',
			),
			"description" => '',
			"admin_label" => true,
			"group" => __( "Second Button", "grve-vc-extension" ),
		),
		array(
			"type" => "vc_link",
			"heading" => __( "Second Button Link", "grve-vc-extension" ),
			"param_name" => "button2_link",
			"value" => "",
			"description" => __( "Enter a link for your button.", "grve-vc-extension" ),
			"group" => __( "Second Button", "grve-vc-extension" ),
		),
		$grve_vce_add_align,
		$grve_vce_add_animation,
		$grve_vce_add_animation_delay,
		$grve_vce_add_margin_bottom,
		$grve_vce_add_el_class,
	),
) );
?>