<?php
/**
 * Team Shortcode
 */

if( !function_exists( 'grve_team_shortcode' ) ) {

	function grve_team_shortcode( $attr, $content ) {

		$output = $data = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'image' => '',
					'hover_image' => '',
					'team_style' => 'classic',
					'name' => '',
					'identity' => '',
					'social_facebook' => '',
					'social_twitter' => '',
					'social_linkedin' => '',
					'email' => '',
					'link' => '',
					'animation' => '',
					'animation_delay' => '200',
					'margin_bottom' => '',
					'el_class' => '',
				),
				$attr
			)
		);

		$image_size = 'grve-image-medium-team';
		$image_class = 'grve-team-person';
		if ( 'hover' == $team_style ) {
			$image_size = 'grve-image-small-rect';
			$image_class = 'grve-first-image';
		}

		$style = grve_vce_build_margin_bottom_style( $margin_bottom );

		$image_string = $image2_string = '';

		if ( !empty( $image ) ) {
			$id = preg_replace('/[^\d]/', '', $image);
			$thumb_src = wp_get_attachment_image_src( $id, $image_size );
			$image_src = $thumb_src[0];
			$alt = get_post_meta( $id, '_wp_attachment_image_alt', true );
			$alt = ! empty( $alt ) ? esc_attr( $alt ) : '';
		} else {
			$image_src = GRVE_VC_EXT_PLUGIN_DIR_URL .'assets/images/empty/' . $image_size . '.jpg';
			$alt = "Empty Team";
		}

		$image_string .= '  <img class="' . $image_class . '" src="' . $image_src . '" alt="' . $alt . '">';


		if ( 'hover' == $team_style ) {
			if ( !empty( $hover_image ) ) {
				$id = preg_replace('/[^\d]/', '', $hover_image);
				$thumb_src = wp_get_attachment_image_src( $id, $image_size );
				$image_src = $thumb_src[0];
				$alt = get_post_meta( $id, '_wp_attachment_image_alt', true );
				$alt = ! empty( $alt ) ? esc_attr( $alt ) : '';
			}

			$image2_string .= '  <img class="grve-second-image" src="' . $image_src . '" alt="' . $alt . '">';
		}

		if ( !empty( $link ) ){
			$href = vc_build_link( $link );
			$url = $href['url'];
			if ( !empty( $href['target'] ) ){
				$target = $href['target'];
			} else {
				$target= "_self";
			}
		} else {
			$url = "#";
			$target= "_self";
		}

		$links = '';
		if ( !empty( $social_facebook ) ) {
			$links .= '<li><a href="' . esc_url( $social_facebook ) . '" target="_blank"><i class="fa fa-facebook"></i></a></li>';
		}
		if ( !empty( $social_twitter ) ) {
			$links .= '<li><a href="' . esc_url( $social_twitter ) . '" target="_blank"><i class="fa fa-twitter"></i></a></li>';
		}
		if ( !empty( $social_linkedin ) ) {
			$links .= '<li><a href="' . esc_url( $social_linkedin ) . '" target="_blank"><i class="fa fa-linkedin"></i></a></li>';
		}
		if ( !empty( $email ) ) {
			$links .= '<li><a href="mailto:' . antispambot( $email ) . '"><i class="fa fa-envelope"></i></a></li>';
		}
		if ( !empty( $link ) && 'classic' == $team_style ) {
			$links .= '<li><a href="' . esc_url( $url ) . '" target="' . $target . '"><i class="fa fa-share"></i></a></li>';
		}

		$team_classes = array( 'grve-element' );

		if ( !empty( $animation ) ) {
			array_push( $team_classes, 'grve-animated-item' );
			array_push( $team_classes, $animation);
			$data = ' data-delay="' . $animation_delay . '"';
		}
		if ( !empty( $el_class ) ) {
			array_push( $team_classes, $el_class);
		}
		$team_class_string = implode( ' ', $team_classes );


		ob_start();

		if ( 'hover' == $team_style ) {

		?>

		<div class="grve-smallteam-item <?php echo $team_class_string; ?>" style="<?php echo $style; ?>"<?php echo $data; ?>>
			<div class="grve-person-image">
				<?php
					if ( !empty( $link ) ) {
						echo '<a href="' . esc_url( $url ) . '" target="' . $target . '">';
						echo $image_string;
						echo $image2_string;
						echo '</a>';
					} else {
						echo $image_string;
						echo $image2_string;
					}
				?>
			</div>
			<div class="grve-smallteam-content">
				<span class="grve-team-description"><?php echo $identity; ?></span>
				<span class="grve-team-name"><?php echo $name; ?></span>
			</div>
			<div class="grve-smallteam-social">
				<ul>
					<?php echo $links; ?>
				</ul>
			</div>
		</div>
		<?php
		} else {
		?>

		<div class="grve-team-item <?php echo $team_class_string; ?>" style="<?php echo $style; ?>"<?php echo $data; ?>>
			<div class="grve-team-media">
				<?php echo $image_string; ?>
				<div class="grve-team-social">
					<ul>
						<?php echo $links; ?>
					</ul>
				</div>
			</div>
			<div class="grve-team-content">
				<span class="grve-team-name"><?php echo $name; ?></span>
				<span class="grve-team-description"><?php echo $identity; ?></span>
			</div>
		</div>

		<?php
		}

		return ob_get_clean();

	}
	add_shortcode( 'grve_team', 'grve_team_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

vc_map( array(
	"name" => __( "Team", "grve-vc-extension" ),
	"description" => __( "Show your team members", "grve-vc-extension" ),
	"base" => "grve_team",
	"class" => "",
	"icon"      => "icon-wpb-grve-team",
	"category" => __( "Content", "js_composer" ),
	"params" => array(
		array(
			"type" => "dropdown",
			"heading" => __( "Team style", "grve-vc-extension" ),
			"param_name" => "team_style",
			"value" => array(
				__( "Classic", "grve-vc-extension" ) => 'classic',
				__( "Small Hover", "grve-vc-extension" ) => 'hover',
			),
			"description" => __( "Select your team style.", "grve-vc-extension" ),
			"admin_label" => true,
		),
		array(
			"type" => "attach_image",
			"heading" => __( "Image", "grve-vc-extension" ),
			"param_name" => "image",
			"description" => __( "Select an image.", "grve-vc-extension" ),
		),
		array(
			"type" => "attach_image",
			"heading" => __( "Hover image", "grve-vc-extension" ),
			"param_name" => "hover_image",
			"description" => __( "Select a hover image.", "grve-vc-extension" ),
			"dependency" => Array( 'element' => "team_style", 'value' => array( 'hover' ) ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Name", "grve-vc-extension" ),
			"param_name" => "name",
			"value" => "John Smith",
			"description" => __( "Enter your team name.", "grve-vc-extension" ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Identity", "grve-vc-extension" ),
			"param_name" => "identity",
			"value" => "Designer",
			"description" => __( "Enter your team identity/profession e.g: Designer", "grve-vc-extension" ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Facebook", "grve-vc-extension" ),
			"param_name" => "social_facebook",
			"value" => "",
			"description" => __( "Enter facebook URL. Clear input if you don't want to display.", "grve-vc-extension" ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Twitter", "grve-vc-extension" ),
			"param_name" => "social_twitter",
			"value" => "",
			"description" => __( "Enter twitter URL. Clear input if you don't want to display.", "grve-vc-extension" ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Linkedin", "grve-vc-extension" ),
			"param_name" => "social_linkedin",
			"value" => "",
			"description" => __( "Enter linkedin URL. Clear input if you don't want to display.", "grve-vc-extension" ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Email", "grve-vc-extension" ),
			"param_name" => "email",
			"value" => "",
			"description" => __( "Enter your email. Clear input if you don't want to display.", "grve-vc-extension" ),
		),
		array(
			"type" => "vc_link",
			"heading" => __( "Link", "grve-vc-extension" ),
			"param_name" => "link",
			"value" => "",
			"description" => __( "Enter link.", "grve-vc-extension" ),
		),
		$grve_vce_add_animation,
		$grve_vce_add_animation_delay,
		$grve_vce_add_margin_bottom,
		$grve_vce_add_el_class,
	)
) );

?>