<?php
/**
 * Testimonial Shortcode
 */

if( !function_exists( 'grve_testimonial_shortcode' ) ) {

	function grve_testimonial_shortcode( $attr, $content ) {

		$portfolio_row_start = $allow_filter = $class_fullwidth = $slider_data = $output = $el_class = '';

		extract(
			shortcode_atts(
				array(
					'categories' => '',
					'nav_style' => 'horizontal',
					'items_to_show' => '20',
					'margin_bottom' => '',
					'slideshow_speed' => '3000',
					'smooth_height' => 'yes',
					'el_class' => '',
				),
				$attr
			)
		);

		$testimonial_classes = array( 'grve-element', 'grve-testimonial-carousel' );

		if ( 'vertical' == $nav_style ) {
			array_push( $testimonial_classes, 'grve-style-2');
		}

		if ( !empty ( $el_class ) ) {
			array_push( $testimonial_classes, $el_class);
		}
		$testimonial_class_string = implode( ' ', $testimonial_classes );

		$style = grve_vce_build_margin_bottom_style( $margin_bottom );

		$slider_data .= ' data-slider-speed="' . $slideshow_speed . '"';
		$slider_data .= ' data-slider-smoothheight="' . $smooth_height . '"';

		$testimonial_cat = "";

		if ( !empty( $categories ) ) {
			$testimonial_category_list = explode( ",", $categories );
			foreach ( $testimonial_category_list as $testimonial_list ) {
				$testimonial_term = get_term( $testimonial_list, 'testimonial_category' );
				$testimonial_cat = $testimonial_cat.$testimonial_term->slug . ', ';
			}
		}

		$args = array(
			'post_type' => 'testimonial',
			'post_status'=>'publish',
			'paged' => 1,
			'testimonial_category' => $testimonial_cat,
			'posts_per_page' => $items_to_show,
		);

		$query = new WP_Query( $args );

		ob_start();

		if ( $query->have_posts() ) :

		?>
			<div class="<?php echo $testimonial_class_string; ?>" style="<?php echo $style; ?>"<?php echo $slider_data; ?>>
				<ul class="slides">

		<?php
		while ( $query->have_posts() ) : $query->the_post();


		$name =  grve_post_meta( 'grve_testimonial_name' );
		$identity =  grve_post_meta( 'grve_testimonial_identity' );

		if ( !empty( $identity ) ) {
			$identity = ', ' . $identity;
		}

		?>
					<li class="grve-testimonial-element">
						<div class="grve-testimonial-content">
							<?php the_content(); ?>
							<div class="grve-testimonial-name"><?php echo $name . $identity; ?></div>
						</div>
					</li>
		<?php
		endwhile;

		?>
				</ul>
			</div>

		<?php
		else :
		endif;
		wp_reset_postdata();

		return ob_get_clean();

	}
	add_shortcode( 'grve_testimonial', 'grve_testimonial_shortcode' );

}

/**
 * Add shortcode to Visual Composer
 */

vc_map( array(
	"name" => __( "Testimonial", "grve-vc-extension" ),
	"description" => __( "Add a captivating testimonial slider", "grve-vc-extension" ),
	"base" => "grve_testimonial",
	"class" => "",
	"icon"      => "icon-wpb-grve-testimonial",
	"category" => __( "Content", "js_composer" ),
	"params" => array(
		array(
			"type" => "dropdown",
			"heading" => __( "Navigation Style", "grve-vc-extension" ),
			"param_name" => "nav_style",
			"admin_label" => true,
			'value' => array(
				__( 'Horizontal' , 'grve-vc-extension' ) => 'horizontal',
				__( 'Vertical' , 'grve-vc-extension' ) => 'vertical',
			),
			"description" => __( "Select a style for your testimonial navigation.", "grve-vc-extension" ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Items to show", "grve-vc-extension" ),
			"param_name" => "items_to_show",
			"value" => '20',
			"description" => __( "Maximum Testimonial Items to Show", "grve-vc-extension" ),
		),
		array(
			"type" => "textfield",
			"heading" => __( "Slideshow Speed", "grve-vc-extension" ),
			"param_name" => "slideshow_speed",
			"value" => '3000',
			"description" => __( "Slideshow Speed in ms.", "grve-vc-extension" ),
		),
		array(
			"type" => "dropdown",
			"heading" => __( "Smooth Height", "grve-vc-extension" ),
			"param_name" => "smooth_height",
			"admin_label" => true,
			'value' => array(
				__( 'Yes' , 'grve-vc-extension' ) => 'yes',
				__( 'No' , 'grve-vc-extension' ) => 'no',
			),
			"description" => __( "Select if you want smooth auto height.", "grve-vc-extension" ),
		),
		array(
			"type" => "grve_multi_checkbox",
			"heading" => __("Testimonial Categories", "grve-vc-extension" ),
			"param_name" => "categories",
			"value" => grve_vce_get_testimonial_categories(),
			"description" => __( "Select all or multiple categories.", "grve-vc-extension" ),
			"admin_label" => true,
			"group" => __( "Categories", "grve-vc-extension" ),
		),
		$grve_vce_add_margin_bottom,
		$grve_vce_add_el_class,
	)
) );

?>